/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_3Q_HPP_
#define _HEAVY_CONTEXT_WSTD_3Q_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlSystem.h"
#include "HvControlUnop.h"
#include "HvMath.h"
#include "HvSignalVar.h"
#include "HvControlSlice.h"
#include "HvControlCast.h"
#include "HvSignalLine.h"
#include "HvControlBinop.h"
#include "HvControlIf.h"
#include "HvSignalBiquad.h"
#include "HvControlVar.h"

class Heavy_WSTD_3Q : public HeavyContext {

 public:
  Heavy_WSTD_3Q(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_3Q();

  const char *getName() override { return "WSTD_3Q"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 6; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_WVIQvl2i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Gz9sjHTX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PRNMX3Io_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4hktxAjy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_cGgNGLYl_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_mXPOsNRM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_c2lONnp6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_GEhwhcmc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LRFkeLYk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_cIDm15LO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_jL3m6kJd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SSZygHsW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wlMXFJ4D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SAXInk7l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WP8Icp1O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MjWeuVBm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5DvDZk1K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7eYw05Ls_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jF9QG4QO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fgeGehr3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_4IR8LIT6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QIcG5Dju_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1yEUee21_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0wIti6fN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ezJGWAGI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_80go78s6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XPPO2Drr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EJIjsS2T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FQVmzeF7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XetwcfRP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HM6O0Nla_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_um5EAI0V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_XlIHfeDt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_8Lva51nd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yQ4DIARG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lyFjKAMO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uxSCzZPC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_i422Xnii_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tdiJWFoL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zm8QCthb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_alK4Hzgk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TKgd7Byg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Cnk5jwjC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_BnZyr5qg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ARxlq0MU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7T7y1UZb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_I1SNvNIf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tvqQKYPz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WRS0GPVv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wcYNRloL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vLiqhSTx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_h3rE58qC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lGF8HTqy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_klgdkJoX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6K7KKgbV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_QugGQpci_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_rbk0ifCa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_G6x9danT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LmRXQrgF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_clM22pVJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nE9zH92F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5bO45EoP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uN2ozgQV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jg5QG7s6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wpkToShs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jUoYTR8q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_U9Gl6t5Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i2rxfTnv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4gLQl2zP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hwUS2qq3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G1FudZaa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oJKTSq4F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O9kIt49E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qFqw6RML_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6g5gfIuK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_38vZfqam_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_p9SZ7PaZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_zNsURazG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ANUhF3l8_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_AGTeKrkG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GRtmfjUn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_UKHjpfXO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_e1lp8YDz_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_dNLi7sMo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KljjVvzc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_SP3dns0t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_v4ma11dY_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_9GLivCxM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XEKLihdL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_zVy8SZWp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_usimqyvc_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_axW1C7MF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_k61tyITU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_yk8vaQJV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aux1SU9A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_j02kkfHF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4ajreCTY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_d8I5qyY3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FyDMugKg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zXgJb00c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_oGLtCxtX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_aZVGXnO5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WBYuFPc4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wB96VSi3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zxphkhlM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tcNuxzEy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dYl9m1o8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_OQhvIdlU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_SndfaHO4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pwukWjjy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JNrJq3tg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3ytDwzaN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RVHX3EZg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wapCMolw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_E84OseML_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_beOyIQX1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OLZbyHsL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NWpe0Ost_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zQZP5hCE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1Q0JWt33_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3xRskJG8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tbZKuKdO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SFMoA12G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_opq58938_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GUq8zO3W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_O2A7DT4m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tvx8HfOI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MR6MFYqD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_fu83QjfA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_E57M5dTh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_NkjPWHkz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KfiKABkx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6KGH08My_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3UWHavl3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_owQ1mmhl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_w85Mxl8X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pF9t0YP7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x1fHuL0i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_w1C3uRp7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fUXOLSr1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_w5szpzzX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NAJGIX9W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kwNVh5Tp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ncCipAGM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HuuK17JY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3M6VV0f6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2ZWnf68X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1W9IkqPU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LkcUoRbL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_waFShc9M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HKLLTiKF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zRyvWAaV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dzePqj2h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_n2mGETwv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LcOSWj3r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5NQullXc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_R0fLBubY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_U3Pzg3Bw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_gAWlCKf6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4d7vDwd9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_epq7DuGT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3svM99YJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BPO7Y7aI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZMqypNgF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_f73XzB0y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_QkmVkBdU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_l2cAAJkQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wtdOkkXL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xQ17Deob_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gOta1wIu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b2kzPzIV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FHdMN9SS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YoQhfXHK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dnaIiW4M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q6MM7MQf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_t9sFiscd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6FkDAu6u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WJQpMxts_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_i5K65WZX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4ie6p4HB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_d6XxcNfw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_f9lOXik8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Q3tCGHia_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NNYwjKb3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TcwkpHsN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZJ83yUCa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xzVmAEci_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SG6baHsC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_js8HstAG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mnSruftM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n1eptIzy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tPf9a8E4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BAjzYn9S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3SMyRQ50_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GqsNvTaE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eovkFC7D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JcwIw7uc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rXO1GHsF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_S85k9A3U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2ab5PYpz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qEJXNvyk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eZNoIp7l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2AOqK5OW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hIlNE3ap_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_csSoNiwo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jmcowVb0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vEm9mvho_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_SoKXrXSv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_3BLwopCJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jsOyAE26_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_P6nsjEkc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ef84D1CH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6uwAFqRq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_A8dQHQvQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_JZSlF2pw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_h3TWL3pO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RU5uuiHC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j1VBA9Vx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BcNQnm6I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_deoI3jSO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uWpHlM3u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N2oJY714_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YwvxpdDj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zI7cWgw3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VUV15k0J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rhgqLgSa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fQTKLgr5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MR6A2BHJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7uAsbQzE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gbnEYh0b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_l9kOOP4o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_My617zuL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_j4StFXQY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vZ3aLfFO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5S6Q54Sc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_q8ZJhkpq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8ViDfDMI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_v3zvh1ux_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_T3ZgzA1A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_IWJOddtB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_98sCKhEC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6fSOoB1Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Wm7YDQtD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SoR7eV6p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3sPpgAv6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hmkUrWEl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KMVI0tIX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xIZO3URb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2Bx0jawL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QB1ewlnG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4KfNUE0a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_U7v2fcOu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rg73gm4t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ELojhr6h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VcPjmLju_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5gIvw6lj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Bz437peZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_s6Hd6UTa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zvpjNXzc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ksq2HWMT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XHNdfPqb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KvlitUgZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0p0j7B3T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iYylFnJ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nio0xBg8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_GXDBDnXi_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_OcOjo4PN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_D1OZANoJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_3iIH6GtT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_INnNSc5H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_nIe1pZ5f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_hgzLEwuW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZuslymTN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6Aiclp76_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nXRKUeyZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_D88x1eRg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_R9iVgkC2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AjG0p9rx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iudO5f7j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_i1gakCqZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PeFiCiRm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_FCLlWEw2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MP7k2FuO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7B5NEHMl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F9SfufSZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZcJWUNw8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4Pwxemi5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V4D2lE8z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1oIiZAOH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gEgyNygY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hWVXIzYe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sKHmsFke_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9sAtPRrg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_PpBOTr3M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_PjD9uTp9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_U8raZsgc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nJB0VH40_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zEgtKZOd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_I7CAxeHp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fR976nAh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9lygLoAv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_36w7OjOQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_56ZjkOZl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BeIhLM7E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_WG9lNND8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_154q2OdM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7I2gVXDb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GuS97kQ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CnD1roHE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pua5liL1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Jj25Mkf7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CRE3wd8O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kd9JHx5w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_D8xeHo5g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_e4i0V9zl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wDCT7eXJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_rjFzu4jZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_0IUz2f4y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fV5gk8SO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mHx1Oc6o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5lwrd6QI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WIg5CEqR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_C6tNCKfg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n1IMWyWU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tXZY3Zrj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_McH1WUN8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EpnWRV3x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_GuRpe4Ve_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OHyFzTnU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aqKmdrF3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XINdJ86u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VLjN5ucu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_66AaMgLF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PlnvV4rv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AbeqJoVy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YM27BjJm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AkhlSbC9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lec2EjI0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_1QvnIlMH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_WYsgT8sT_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_C1TK6wkD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XHpwpgq7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_juksP4s4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_3XhmDOhA_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_BjBDbzV6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Eal9tcJu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Rop9tTeQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_yd9JHYqO_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_48B64ovD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ImwSkEzZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_zKgNAQC3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_F0uB9b99_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_hSFNEClR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3nnhlgZq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_xdxKIN7p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JfocG4Wh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iYUYVwJZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3ZLpNQOz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_C7uaLIIk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Vk7oITCK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qzTs9QhZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_rXpCDkvd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_TYCPWi7x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_spCekacs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wJZLVNYf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_w1UJO7Pw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cApFGrZO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PhH3YTL3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_3VsAuP7H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_fdrFnjRb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wXcugilO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jcZvPIIf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7YEtDOXl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nWJF6QqF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XpuNb8WU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zH0LXJyK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5xa10fu7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yLptm1dD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Oy1T1zMo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9zYvLEAp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NmA4XrRs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fmvJECtx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5SX6i9LH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_74hUczmj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KjxKBrTK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2Ndu72Uk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FXdDNwEV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MxqCqb7E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1O5OKP64_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_NkeebdF9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_3O7W6dS4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ZHp8KowN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BQdbCZom_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ee7nJrtS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mzTTnmWf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WRgJxMVG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7nQsWv9g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zNREwacO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vesjZN1g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZuySSA7N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wh4D2RXZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9HGMS2aE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sSrqDYpu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5DTG6DxN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WI1qpRWW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_J0hBmVCU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rRVgcJks_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DOLmRSxD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vXpRlQC3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7E2oXWQU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wJxXcS3h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1JcwWPjG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1wswlL0p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BXvU83lz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_07QdDoOo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sUmACYYk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RL1k52oc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vvBMsa02_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_znYsC5gD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Mk30IkkI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xKmKFfVX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aK1MkFdk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bixEka1W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nI8YCaTL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_grEYILya_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_pbpmunDY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_5AJRcEFP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Dc3Yvuqi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QiB8R7Va_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Dm4HwqKy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mYXdYsWJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Tg2QVT4T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_E4RzUcnz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5AxnQuX6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zIixQcUB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CkNzhJUi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_w9PIKwto_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IYo0mRdH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vKiF76Xm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iLGggi5V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RKc032p7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_tzbQjIsz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_plZ3zT3p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_uS2nDULc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1rlnCEe0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gCRjiFyK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ODzH6zDR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DwgHddaz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VWnvRqlL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vCKtEjdZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CM4z62Kq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SbM7pZVx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IpyuyyI4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zjYBmmi2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LtAepNBX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NTMQ1QGa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TYK3ENcs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AGCTb32e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BfKFX0tx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AKB1tvZp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jMucQImO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ArF4zMG5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OBlMoQ14_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XZknpYDa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eQc1RmDP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_w6ioNvGQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XKsVddh0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5bstRgzu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_dfhfo8sE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_FdqXSBtm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MXqgamPJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_goygDkWU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZFDXR1E1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fKQL6lJf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lnkYlyU6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_U46MpFjC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_iJu3Kio0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9IfnsbtE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iGwJOzsl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wb4Xeotx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u5xjarSq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_olmEHUFH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Pde2qjvY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AebRNlqh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bWftEM10_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K6SPwUzE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XnsBbHnU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2wwsVaqM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XpNaug2J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9Clhqr0C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GDFlVqBJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_urfhjlec_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oumS1o3o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dHmXKQ4X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2exLqDsC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WN6Awgyd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NPOhqGs5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_j64zx8kk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_kOFETNER_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_fDrq8QQZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_v7vsawGn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_D3KKCbPF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qFAGoO0Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3KfP6ung_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9ydt4hFQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fMmU2fI5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uqLNYjVL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XgmWD6DY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6CXA0PuG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_43opcpbM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LJ2bJZgm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_htaxz3bP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qV1Fzo8Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Lx1SDrns_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OE9AVtAE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BjlV7R7L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2q0hMuca_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8eKuxGDy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_g6tqEYsu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7waKYYBH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fxvXlJGI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_N71aWr4n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d63c7Kq0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zNIeybuL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bsEb9PIJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JEP8Qmct_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jpvptTQF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dZVW0D7p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_oh5gLJok_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_aG4sn3M0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_80zyfCd0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_A6pwxbgw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7F5l4mpD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Nfd23mIN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yp1cOWgu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8E4wK3RZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_gt5PjDGs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UCZwEFLm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5z8XK1Pi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O8EAwN4r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Uawi0zFQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4iw5EAr3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hoNuJvrl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YE62uyrf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Y6UNn05O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bz2Nt7fz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zMNCuMko_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FzBVGBXy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_nrgNcEvA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DshYfIDk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_q4O32XG4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_RLQ2mTKc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_T5oUzL6T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_PDKjVEJT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fERXOpmo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vR7Hcnwd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5h7kQsoF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DNjIZwlF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_n2ILdULZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_HQh47ZhD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_nL7ee1OM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_T1JQPv0V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_HDwnzypY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_kzexmikP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_EHmcnDn2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_NZkuTUO5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_AlywEk4N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_iIJaKeJF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_s97ZefgI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_okkEDIx1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_byyZKIwX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9B1T2xbn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_KQ3omudN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_AOejFoe8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xbyfX8yl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3TTcRhEE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ToQ25979_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_nAHgcNiR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Hl36JBKc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_37DZq7SY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_TUM2PEhL_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_EI11ewnL;
  SignalLine sLine_1WAMXRht;
  SignalLine sLine_e2OkLuhA;
  SignalLine sLine_qUig6pxo;
  SignalLine sLine_Ul95qGZT;
  SignalBiquad sBiquad_s_Y5N28MCe;
  SignalLine sLine_UWAhCuob;
  SignalLine sLine_JDAbuf1l;
  SignalLine sLine_ORG3XQA2;
  SignalLine sLine_UKHwqQyX;
  SignalBiquad sBiquad_s_QMaImNZI;
  SignalLine sLine_ixoHh2vN;
  SignalLine sLine_s1lza5bT;
  SignalLine sLine_tuagJxEp;
  SignalLine sLine_MmKKMS8E;
  SignalLine sLine_C3j9GkWc;
  SignalBiquad sBiquad_s_nb7ZKiZ3;
  SignalLine sLine_8HMvtAGd;
  SignalLine sLine_tIAn1zmQ;
  SignalLine sLine_QuBm5rX0;
  SignalLine sLine_nWARzAsP;
  SignalLine sLine_ETNpItDQ;
  SignalBiquad sBiquad_s_bsPenzoi;
  SignalLine sLine_sIxI6B5A;
  SignalLine sLine_aDcDA4hB;
  SignalLine sLine_zx7h5ibi;
  SignalLine sLine_QVIrEG1r;
  SignalBiquad sBiquad_s_RatCbAyY;
  SignalLine sLine_7ipPLhUR;
  SignalLine sLine_4nDatD9R;
  SignalLine sLine_0OLoKptJ;
  SignalLine sLine_ccRk3ax9;
  SignalLine sLine_eeJ8AsEA;
  SignalBiquad sBiquad_s_bl8uZm98;
  ControlVar cVar_WVIQvl2i;
  ControlVar cVar_Gz9sjHTX;
  ControlVar cVar_PRNMX3Io;
  ControlVar cVar_4hktxAjy;
  ControlSlice cSlice_mXPOsNRM;
  ControlVar cVar_c2lONnp6;
  ControlVar cVar_LRFkeLYk;
  ControlIf cIf_cIDm15LO;
  ControlIf cIf_jL3m6kJd;
  ControlBinop cBinop_wlMXFJ4D;
  ControlBinop cBinop_SAXInk7l;
  ControlBinop cBinop_5DvDZk1K;
  ControlBinop cBinop_7eYw05Ls;
  ControlBinop cBinop_fgeGehr3;
  ControlIf cIf_4IR8LIT6;
  ControlBinop cBinop_QIcG5Dju;
  ControlBinop cBinop_1yEUee21;
  ControlBinop cBinop_ezJGWAGI;
  ControlBinop cBinop_80go78s6;
  ControlBinop cBinop_XPPO2Drr;
  ControlVar cVar_um5EAI0V;
  ControlIf cIf_XlIHfeDt;
  ControlIf cIf_8Lva51nd;
  ControlBinop cBinop_lyFjKAMO;
  ControlBinop cBinop_uxSCzZPC;
  ControlBinop cBinop_Zm8QCthb;
  ControlBinop cBinop_alK4Hzgk;
  ControlBinop cBinop_Cnk5jwjC;
  ControlIf cIf_BnZyr5qg;
  ControlBinop cBinop_ARxlq0MU;
  ControlBinop cBinop_7T7y1UZb;
  ControlBinop cBinop_tvqQKYPz;
  ControlBinop cBinop_WRS0GPVv;
  ControlBinop cBinop_wcYNRloL;
  ControlVar cVar_6K7KKgbV;
  ControlIf cIf_QugGQpci;
  ControlIf cIf_rbk0ifCa;
  ControlBinop cBinop_LmRXQrgF;
  ControlBinop cBinop_clM22pVJ;
  ControlBinop cBinop_uN2ozgQV;
  ControlBinop cBinop_jg5QG7s6;
  ControlBinop cBinop_jUoYTR8q;
  ControlIf cIf_U9Gl6t5Y;
  ControlBinop cBinop_i2rxfTnv;
  ControlBinop cBinop_4gLQl2zP;
  ControlBinop cBinop_G1FudZaa;
  ControlBinop cBinop_oJKTSq4F;
  ControlBinop cBinop_O9kIt49E;
  ControlIf cIf_zNsURazG;
  ControlSlice cSlice_AGTeKrkG;
  ControlVar cVar_GRtmfjUn;
  ControlSlice cSlice_dNLi7sMo;
  ControlVar cVar_KljjVvzc;
  ControlSlice cSlice_9GLivCxM;
  ControlVar cVar_XEKLihdL;
  ControlSlice cSlice_axW1C7MF;
  ControlVar cVar_k61tyITU;
  ControlBinop cBinop_wB96VSi3;
  ControlBinop cBinop_tcNuxzEy;
  ControlBinop cBinop_dYl9m1o8;
  ControlBinop cBinop_pwukWjjy;
  ControlBinop cBinop_JNrJq3tg;
  ControlBinop cBinop_3ytDwzaN;
  ControlBinop cBinop_RVHX3EZg;
  ControlBinop cBinop_wapCMolw;
  ControlVar cVar_E84OseML;
  ControlBinop cBinop_beOyIQX1;
  ControlBinop cBinop_OLZbyHsL;
  ControlBinop cBinop_NWpe0Ost;
  ControlBinop cBinop_zQZP5hCE;
  ControlBinop cBinop_1Q0JWt33;
  ControlBinop cBinop_3xRskJG8;
  ControlBinop cBinop_tbZKuKdO;
  ControlBinop cBinop_opq58938;
  ControlVar cVar_GUq8zO3W;
  ControlVar cVar_O2A7DT4m;
  ControlBinop cBinop_6KGH08My;
  ControlBinop cBinop_3UWHavl3;
  ControlBinop cBinop_owQ1mmhl;
  ControlBinop cBinop_pF9t0YP7;
  ControlBinop cBinop_x1fHuL0i;
  ControlBinop cBinop_w1C3uRp7;
  ControlBinop cBinop_fUXOLSr1;
  ControlBinop cBinop_w5szpzzX;
  ControlBinop cBinop_NAJGIX9W;
  ControlBinop cBinop_epq7DuGT;
  ControlBinop cBinop_BPO7Y7aI;
  ControlBinop cBinop_ZMqypNgF;
  ControlBinop cBinop_l2cAAJkQ;
  ControlBinop cBinop_wtdOkkXL;
  ControlBinop cBinop_xQ17Deob;
  ControlBinop cBinop_gOta1wIu;
  ControlBinop cBinop_b2kzPzIV;
  ControlBinop cBinop_FHdMN9SS;
  ControlBinop cBinop_YoQhfXHK;
  ControlBinop cBinop_Q6MM7MQf;
  ControlVar cVar_t9sFiscd;
  ControlVar cVar_6FkDAu6u;
  ControlVar cVar_WJQpMxts;
  ControlBinop cBinop_TcwkpHsN;
  ControlBinop cBinop_ZJ83yUCa;
  ControlBinop cBinop_xzVmAEci;
  ControlBinop cBinop_js8HstAG;
  ControlBinop cBinop_mnSruftM;
  ControlBinop cBinop_n1eptIzy;
  ControlBinop cBinop_tPf9a8E4;
  ControlBinop cBinop_BAjzYn9S;
  ControlBinop cBinop_P6nsjEkc;
  ControlBinop cBinop_6uwAFqRq;
  ControlBinop cBinop_A8dQHQvQ;
  ControlBinop cBinop_RU5uuiHC;
  ControlBinop cBinop_j1VBA9Vx;
  ControlBinop cBinop_BcNQnm6I;
  ControlBinop cBinop_deoI3jSO;
  ControlBinop cBinop_uWpHlM3u;
  ControlBinop cBinop_YwvxpdDj;
  ControlBinop cBinop_VUV15k0J;
  ControlBinop cBinop_rhgqLgSa;
  ControlBinop cBinop_MR6A2BHJ;
  ControlBinop cBinop_7uAsbQzE;
  ControlBinop cBinop_gbnEYh0b;
  ControlBinop cBinop_My617zuL;
  ControlVar cVar_j4StFXQY;
  ControlVar cVar_vZ3aLfFO;
  ControlVar cVar_5S6Q54Sc;
  ControlBinop cBinop_6fSOoB1Q;
  ControlBinop cBinop_Wm7YDQtD;
  ControlBinop cBinop_SoR7eV6p;
  ControlBinop cBinop_hmkUrWEl;
  ControlBinop cBinop_KMVI0tIX;
  ControlBinop cBinop_xIZO3URb;
  ControlBinop cBinop_2Bx0jawL;
  ControlBinop cBinop_QB1ewlnG;
  ControlBinop cBinop_4KfNUE0a;
  ControlBinop cBinop_KvlitUgZ;
  ControlBinop cBinop_iYylFnJ5;
  ControlBinop cBinop_nio0xBg8;
  SignalVarf sVarf_uWzphsaV;
  SignalVarf sVarf_p0Yiwb6q;
  SignalVarf sVarf_EImZXKEC;
  ControlSlice cSlice_OcOjo4PN;
  ControlVar cVar_D1OZANoJ;
  ControlVar cVar_INnNSc5H;
  ControlIf cIf_nIe1pZ5f;
  ControlIf cIf_hgzLEwuW;
  ControlBinop cBinop_6Aiclp76;
  ControlBinop cBinop_nXRKUeyZ;
  ControlBinop cBinop_AjG0p9rx;
  ControlBinop cBinop_iudO5f7j;
  ControlBinop cBinop_PeFiCiRm;
  ControlIf cIf_FCLlWEw2;
  ControlBinop cBinop_MP7k2FuO;
  ControlBinop cBinop_7B5NEHMl;
  ControlBinop cBinop_ZcJWUNw8;
  ControlBinop cBinop_4Pwxemi5;
  ControlBinop cBinop_V4D2lE8z;
  ControlVar cVar_9sAtPRrg;
  ControlIf cIf_PpBOTr3M;
  ControlIf cIf_PjD9uTp9;
  ControlBinop cBinop_nJB0VH40;
  ControlBinop cBinop_zEgtKZOd;
  ControlBinop cBinop_9lygLoAv;
  ControlBinop cBinop_36w7OjOQ;
  ControlBinop cBinop_BeIhLM7E;
  ControlIf cIf_WG9lNND8;
  ControlBinop cBinop_154q2OdM;
  ControlBinop cBinop_7I2gVXDb;
  ControlBinop cBinop_CnD1roHE;
  ControlBinop cBinop_pua5liL1;
  ControlBinop cBinop_Jj25Mkf7;
  ControlVar cVar_wDCT7eXJ;
  ControlIf cIf_rjFzu4jZ;
  ControlIf cIf_0IUz2f4y;
  ControlBinop cBinop_mHx1Oc6o;
  ControlBinop cBinop_5lwrd6QI;
  ControlBinop cBinop_n1IMWyWU;
  ControlBinop cBinop_tXZY3Zrj;
  ControlBinop cBinop_EpnWRV3x;
  ControlIf cIf_GuRpe4Ve;
  ControlBinop cBinop_OHyFzTnU;
  ControlBinop cBinop_aqKmdrF3;
  ControlBinop cBinop_VLjN5ucu;
  ControlBinop cBinop_66AaMgLF;
  ControlBinop cBinop_PlnvV4rv;
  ControlIf cIf_1QvnIlMH;
  ControlSlice cSlice_C1TK6wkD;
  ControlVar cVar_XHpwpgq7;
  ControlSlice cSlice_BjBDbzV6;
  ControlVar cVar_Eal9tcJu;
  ControlSlice cSlice_48B64ovD;
  ControlVar cVar_ImwSkEzZ;
  ControlSlice cSlice_hSFNEClR;
  ControlVar cVar_3nnhlgZq;
  ControlBinop cBinop_wJZLVNYf;
  ControlBinop cBinop_cApFGrZO;
  ControlBinop cBinop_PhH3YTL3;
  ControlBinop cBinop_wXcugilO;
  ControlBinop cBinop_jcZvPIIf;
  ControlBinop cBinop_7YEtDOXl;
  ControlBinop cBinop_nWJF6QqF;
  ControlBinop cBinop_XpuNb8WU;
  ControlVar cVar_zH0LXJyK;
  ControlBinop cBinop_5xa10fu7;
  ControlBinop cBinop_yLptm1dD;
  ControlBinop cBinop_Oy1T1zMo;
  ControlBinop cBinop_9zYvLEAp;
  ControlBinop cBinop_NmA4XrRs;
  ControlBinop cBinop_fmvJECtx;
  ControlBinop cBinop_5SX6i9LH;
  ControlBinop cBinop_KjxKBrTK;
  ControlVar cVar_2Ndu72Uk;
  ControlVar cVar_FXdDNwEV;
  ControlBinop cBinop_Ee7nJrtS;
  ControlBinop cBinop_mzTTnmWf;
  ControlBinop cBinop_WRgJxMVG;
  ControlBinop cBinop_zNREwacO;
  ControlBinop cBinop_vesjZN1g;
  ControlBinop cBinop_ZuySSA7N;
  ControlBinop cBinop_wh4D2RXZ;
  ControlBinop cBinop_9HGMS2aE;
  ControlBinop cBinop_sSrqDYpu;
  ControlBinop cBinop_aK1MkFdk;
  ControlBinop cBinop_nI8YCaTL;
  ControlBinop cBinop_grEYILya;
  ControlBinop cBinop_Dc3Yvuqi;
  ControlBinop cBinop_QiB8R7Va;
  ControlBinop cBinop_Dm4HwqKy;
  ControlBinop cBinop_mYXdYsWJ;
  ControlBinop cBinop_Tg2QVT4T;
  ControlBinop cBinop_E4RzUcnz;
  ControlBinop cBinop_5AxnQuX6;
  ControlBinop cBinop_CkNzhJUi;
  ControlVar cVar_w9PIKwto;
  ControlVar cVar_IYo0mRdH;
  ControlVar cVar_vKiF76Xm;
  ControlBinop cBinop_gCRjiFyK;
  ControlBinop cBinop_ODzH6zDR;
  ControlBinop cBinop_DwgHddaz;
  ControlBinop cBinop_vCKtEjdZ;
  ControlBinop cBinop_CM4z62Kq;
  ControlBinop cBinop_SbM7pZVx;
  ControlBinop cBinop_IpyuyyI4;
  ControlBinop cBinop_zjYBmmi2;
  ControlBinop cBinop_goygDkWU;
  ControlBinop cBinop_fKQL6lJf;
  ControlBinop cBinop_lnkYlyU6;
  ControlBinop cBinop_9IfnsbtE;
  ControlBinop cBinop_iGwJOzsl;
  ControlBinop cBinop_wb4Xeotx;
  ControlBinop cBinop_u5xjarSq;
  ControlBinop cBinop_olmEHUFH;
  ControlBinop cBinop_AebRNlqh;
  ControlBinop cBinop_K6SPwUzE;
  ControlBinop cBinop_XnsBbHnU;
  ControlBinop cBinop_XpNaug2J;
  ControlBinop cBinop_9Clhqr0C;
  ControlBinop cBinop_GDFlVqBJ;
  ControlBinop cBinop_oumS1o3o;
  ControlVar cVar_dHmXKQ4X;
  ControlVar cVar_2exLqDsC;
  ControlVar cVar_WN6Awgyd;
  ControlBinop cBinop_qFAGoO0Z;
  ControlBinop cBinop_3KfP6ung;
  ControlBinop cBinop_9ydt4hFQ;
  ControlBinop cBinop_uqLNYjVL;
  ControlBinop cBinop_XgmWD6DY;
  ControlBinop cBinop_6CXA0PuG;
  ControlBinop cBinop_43opcpbM;
  ControlBinop cBinop_LJ2bJZgm;
  ControlBinop cBinop_htaxz3bP;
  ControlBinop cBinop_d63c7Kq0;
  ControlBinop cBinop_bsEb9PIJ;
  ControlBinop cBinop_JEP8Qmct;
  SignalVarf sVarf_HbL7tmlA;
  SignalVarf sVarf_YCwMU8jl;
  SignalVarf sVarf_ZiPR4jzy;
  ControlVar cVar_jpvptTQF;
  ControlVar cVar_dZVW0D7p;
  ControlBinop cBinop_Nfd23mIN;
  ControlBinop cBinop_yp1cOWgu;
  ControlBinop cBinop_8E4wK3RZ;
  ControlBinop cBinop_UCZwEFLm;
  ControlBinop cBinop_5z8XK1Pi;
  ControlBinop cBinop_O8EAwN4r;
  ControlBinop cBinop_Uawi0zFQ;
};

#endif // _HEAVY_CONTEXT_WSTD_3Q_HPP_
