/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_3Q.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_3Q *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_3Q_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_3Q();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_3Q::Heavy_WSTD_3Q(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_EI11ewnL);
  numBytes += sLine_init(&sLine_1WAMXRht);
  numBytes += sLine_init(&sLine_e2OkLuhA);
  numBytes += sLine_init(&sLine_qUig6pxo);
  numBytes += sLine_init(&sLine_Ul95qGZT);
  numBytes += sBiquad_init(&sBiquad_s_Y5N28MCe);
  numBytes += sLine_init(&sLine_UWAhCuob);
  numBytes += sLine_init(&sLine_JDAbuf1l);
  numBytes += sLine_init(&sLine_ORG3XQA2);
  numBytes += sLine_init(&sLine_UKHwqQyX);
  numBytes += sBiquad_init(&sBiquad_s_QMaImNZI);
  numBytes += sLine_init(&sLine_ixoHh2vN);
  numBytes += sLine_init(&sLine_s1lza5bT);
  numBytes += sLine_init(&sLine_tuagJxEp);
  numBytes += sLine_init(&sLine_MmKKMS8E);
  numBytes += sLine_init(&sLine_C3j9GkWc);
  numBytes += sBiquad_init(&sBiquad_s_nb7ZKiZ3);
  numBytes += sLine_init(&sLine_8HMvtAGd);
  numBytes += sLine_init(&sLine_tIAn1zmQ);
  numBytes += sLine_init(&sLine_QuBm5rX0);
  numBytes += sLine_init(&sLine_nWARzAsP);
  numBytes += sLine_init(&sLine_ETNpItDQ);
  numBytes += sBiquad_init(&sBiquad_s_bsPenzoi);
  numBytes += sLine_init(&sLine_sIxI6B5A);
  numBytes += sLine_init(&sLine_aDcDA4hB);
  numBytes += sLine_init(&sLine_zx7h5ibi);
  numBytes += sLine_init(&sLine_QVIrEG1r);
  numBytes += sBiquad_init(&sBiquad_s_RatCbAyY);
  numBytes += sLine_init(&sLine_7ipPLhUR);
  numBytes += sLine_init(&sLine_4nDatD9R);
  numBytes += sLine_init(&sLine_0OLoKptJ);
  numBytes += sLine_init(&sLine_ccRk3ax9);
  numBytes += sLine_init(&sLine_eeJ8AsEA);
  numBytes += sBiquad_init(&sBiquad_s_bl8uZm98);
  numBytes += cVar_init_f(&cVar_WVIQvl2i, 0.0f);
  numBytes += cVar_init_f(&cVar_Gz9sjHTX, 0.0f);
  numBytes += cVar_init_f(&cVar_PRNMX3Io, 0.0f);
  numBytes += cVar_init_f(&cVar_4hktxAjy, 0.0f);
  numBytes += cSlice_init(&cSlice_mXPOsNRM, 1, -1);
  numBytes += cVar_init_f(&cVar_c2lONnp6, 1337.0f);
  numBytes += cVar_init_f(&cVar_LRFkeLYk, 0.0f);
  numBytes += cIf_init(&cIf_cIDm15LO, false);
  numBytes += cIf_init(&cIf_jL3m6kJd, false);
  numBytes += cBinop_init(&cBinop_wlMXFJ4D, 0.0f); // __pow
  numBytes += cIf_init(&cIf_4IR8LIT6, false);
  numBytes += cBinop_init(&cBinop_ezJGWAGI, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_80go78s6, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_XPPO2Drr, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_um5EAI0V, 0.0f);
  numBytes += cIf_init(&cIf_XlIHfeDt, false);
  numBytes += cIf_init(&cIf_8Lva51nd, false);
  numBytes += cBinop_init(&cBinop_lyFjKAMO, 0.0f); // __pow
  numBytes += cIf_init(&cIf_BnZyr5qg, false);
  numBytes += cBinop_init(&cBinop_tvqQKYPz, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_WRS0GPVv, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_wcYNRloL, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_6K7KKgbV, 0.0f);
  numBytes += cIf_init(&cIf_QugGQpci, false);
  numBytes += cIf_init(&cIf_rbk0ifCa, false);
  numBytes += cBinop_init(&cBinop_LmRXQrgF, 0.0f); // __pow
  numBytes += cIf_init(&cIf_U9Gl6t5Y, false);
  numBytes += cBinop_init(&cBinop_G1FudZaa, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_oJKTSq4F, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_O9kIt49E, -15.0f); // __eq
  numBytes += cIf_init(&cIf_zNsURazG, false);
  numBytes += cSlice_init(&cSlice_AGTeKrkG, 1, -1);
  numBytes += cVar_init_f(&cVar_GRtmfjUn, 0.0f);
  numBytes += cSlice_init(&cSlice_dNLi7sMo, 1, -1);
  numBytes += cVar_init_f(&cVar_KljjVvzc, 0.0f);
  numBytes += cSlice_init(&cSlice_9GLivCxM, 1, -1);
  numBytes += cVar_init_f(&cVar_XEKLihdL, 0.0f);
  numBytes += cSlice_init(&cSlice_axW1C7MF, 1, -1);
  numBytes += cVar_init_f(&cVar_k61tyITU, 0.313f);
  numBytes += cBinop_init(&cBinop_tcNuxzEy, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_dYl9m1o8, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_E84OseML, 0.0f);
  numBytes += cVar_init_f(&cVar_GUq8zO3W, 1337.0f);
  numBytes += cVar_init_f(&cVar_O2A7DT4m, 0.3f);
  numBytes += cBinop_init(&cBinop_3UWHavl3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_x1fHuL0i, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_w1C3uRp7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_fUXOLSr1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_w5szpzzX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NAJGIX9W, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_BPO7Y7aI, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_ZMqypNgF, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_t9sFiscd, 0.0f);
  numBytes += cVar_init_f(&cVar_6FkDAu6u, 1337.0f);
  numBytes += cVar_init_f(&cVar_WJQpMxts, 0.313f);
  numBytes += cBinop_init(&cBinop_ZJ83yUCa, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_mnSruftM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_n1eptIzy, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_tPf9a8E4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_BAjzYn9S, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6uwAFqRq, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_A8dQHQvQ, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_j4StFXQY, 0.0f);
  numBytes += cVar_init_f(&cVar_vZ3aLfFO, 1037.0f);
  numBytes += cVar_init_f(&cVar_5S6Q54Sc, 0.4f);
  numBytes += cBinop_init(&cBinop_Wm7YDQtD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KMVI0tIX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xIZO3URb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2Bx0jawL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QB1ewlnG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4KfNUE0a, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_uWzphsaV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_p0Yiwb6q, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EImZXKEC, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_OcOjo4PN, 1, -1);
  numBytes += cVar_init_f(&cVar_D1OZANoJ, 1337.0f);
  numBytes += cVar_init_f(&cVar_INnNSc5H, 0.0f);
  numBytes += cIf_init(&cIf_nIe1pZ5f, false);
  numBytes += cIf_init(&cIf_hgzLEwuW, false);
  numBytes += cBinop_init(&cBinop_6Aiclp76, 0.0f); // __pow
  numBytes += cIf_init(&cIf_FCLlWEw2, false);
  numBytes += cBinop_init(&cBinop_ZcJWUNw8, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_4Pwxemi5, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_V4D2lE8z, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_9sAtPRrg, 0.0f);
  numBytes += cIf_init(&cIf_PpBOTr3M, false);
  numBytes += cIf_init(&cIf_PjD9uTp9, false);
  numBytes += cBinop_init(&cBinop_nJB0VH40, 0.0f); // __pow
  numBytes += cIf_init(&cIf_WG9lNND8, false);
  numBytes += cBinop_init(&cBinop_CnD1roHE, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_pua5liL1, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_Jj25Mkf7, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_wDCT7eXJ, 0.0f);
  numBytes += cIf_init(&cIf_rjFzu4jZ, false);
  numBytes += cIf_init(&cIf_0IUz2f4y, false);
  numBytes += cBinop_init(&cBinop_mHx1Oc6o, 0.0f); // __pow
  numBytes += cIf_init(&cIf_GuRpe4Ve, false);
  numBytes += cBinop_init(&cBinop_VLjN5ucu, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_66AaMgLF, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_PlnvV4rv, -15.0f); // __eq
  numBytes += cIf_init(&cIf_1QvnIlMH, false);
  numBytes += cSlice_init(&cSlice_C1TK6wkD, 1, -1);
  numBytes += cVar_init_f(&cVar_XHpwpgq7, 0.0f);
  numBytes += cSlice_init(&cSlice_BjBDbzV6, 1, -1);
  numBytes += cVar_init_f(&cVar_Eal9tcJu, 0.0f);
  numBytes += cSlice_init(&cSlice_48B64ovD, 1, -1);
  numBytes += cVar_init_f(&cVar_ImwSkEzZ, 0.0f);
  numBytes += cSlice_init(&cSlice_hSFNEClR, 1, -1);
  numBytes += cVar_init_f(&cVar_3nnhlgZq, 0.313f);
  numBytes += cBinop_init(&cBinop_cApFGrZO, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_PhH3YTL3, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_zH0LXJyK, 0.0f);
  numBytes += cVar_init_f(&cVar_2Ndu72Uk, 1337.0f);
  numBytes += cVar_init_f(&cVar_FXdDNwEV, 0.3f);
  numBytes += cBinop_init(&cBinop_mzTTnmWf, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vesjZN1g, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ZuySSA7N, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_wh4D2RXZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9HGMS2aE, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_sSrqDYpu, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_nI8YCaTL, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_grEYILya, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_w9PIKwto, 0.0f);
  numBytes += cVar_init_f(&cVar_IYo0mRdH, 1337.0f);
  numBytes += cVar_init_f(&cVar_vKiF76Xm, 0.313f);
  numBytes += cBinop_init(&cBinop_ODzH6zDR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_CM4z62Kq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SbM7pZVx, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IpyuyyI4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zjYBmmi2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_fKQL6lJf, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_lnkYlyU6, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_dHmXKQ4X, 0.0f);
  numBytes += cVar_init_f(&cVar_2exLqDsC, 1037.0f);
  numBytes += cVar_init_f(&cVar_WN6Awgyd, 0.4f);
  numBytes += cBinop_init(&cBinop_3KfP6ung, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XgmWD6DY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6CXA0PuG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_43opcpbM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LJ2bJZgm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_htaxz3bP, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_HbL7tmlA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YCwMU8jl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZiPR4jzy, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_jpvptTQF, 5705.6f);
  numBytes += cVar_init_f(&cVar_dZVW0D7p, 313.3f);
  numBytes += cBinop_init(&cBinop_Nfd23mIN, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_yp1cOWgu, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_8E4wK3RZ, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_3Q::~Heavy_WSTD_3Q() {
  // nothing to free
}

HvTable *Heavy_WSTD_3Q::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_3Q::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nrgNcEvA_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_q4O32XG4_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DshYfIDk_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TUM2PEhL_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PDKjVEJT_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fERXOpmo_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RLQ2mTKc_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_T5oUzL6T_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vR7Hcnwd_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HQh47ZhD_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_n2ILdULZ_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DNjIZwlF_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HDwnzypY_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_T1JQPv0V_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nL7ee1OM_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NZkuTUO5_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EHmcnDn2_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kzexmikP_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_s97ZefgI_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_okkEDIx1_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AlywEk4N_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iIJaKeJF_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_byyZKIwX_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AOejFoe8_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KQ3omudN_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9B1T2xbn_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ToQ25979_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3TTcRhEE_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xbyfX8yl_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_37DZq7SY_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Hl36JBKc_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nAHgcNiR_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5h7kQsoF_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_3Q::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_3Q::cVar_WVIQvl2i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4iw5EAr3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_Gz9sjHTX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hoNuJvrl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_PRNMX3Io_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YE62uyrf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_4hktxAjy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y6UNn05O_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7F5l4mpD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A6pwxbgw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_80zyfCd0_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_cGgNGLYl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_mXPOsNRM, 0, m, &cSlice_mXPOsNRM_sendMessage);
      break;
    }
    default: {
      cSwitchcase_v4ma11dY_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_mXPOsNRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GEhwhcmc_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GEhwhcmc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_c2lONnp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GEhwhcmc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_GEhwhcmc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RLQ2mTKc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_LRFkeLYk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_QIcG5Dju_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_cIDm15LO, 0, m, &cIf_cIDm15LO_sendMessage);
}

void Heavy_WSTD_3Q::cIf_cIDm15LO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_1yEUee21_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_jL3m6kJd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_jF9QG4QO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_7eYw05Ls_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_SSZygHsW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wlMXFJ4D, HV_BINOP_POW, 0, m, &cBinop_wlMXFJ4D_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wlMXFJ4D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4IR8LIT6, 0, m, &cIf_4IR8LIT6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SAXInk7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_fgeGehr3_sendMessage);
}

void Heavy_WSTD_3Q::cCast_WP8Icp1O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5DvDZk1K_sendMessage);
}

void Heavy_WSTD_3Q::cCast_MjWeuVBm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jL3m6kJd, 0, m, &cIf_jL3m6kJd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5DvDZk1K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jL3m6kJd, 1, m, &cIf_jL3m6kJd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7eYw05Ls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_SAXInk7l_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_jF9QG4QO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_4IR8LIT6, 0, m, &cIf_4IR8LIT6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_fgeGehr3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wlMXFJ4D, HV_BINOP_POW, 1, m, &cBinop_wlMXFJ4D_sendMessage);
  cMsg_SSZygHsW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_4IR8LIT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_uWzphsaV, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_QIcG5Dju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cIDm15LO, 1, m, &cIf_cIDm15LO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1yEUee21_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_80go78s6, HV_BINOP_GREATER_THAN, 1, m, &cBinop_80go78s6_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XPPO2Drr, HV_BINOP_EQ, 1, m, &cBinop_XPPO2Drr_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_0wIti6fN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ezJGWAGI, HV_BINOP_ADD, 0, m, &cBinop_ezJGWAGI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ezJGWAGI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WP8Icp1O_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MjWeuVBm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_80go78s6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4IR8LIT6, 1, m, &cIf_4IR8LIT6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XPPO2Drr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EJIjsS2T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_EJIjsS2T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_uWzphsaV, m);
}

void Heavy_WSTD_3Q::cCast_FQVmzeF7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LRFkeLYk, 0, m, &cVar_LRFkeLYk_sendMessage);
}

void Heavy_WSTD_3Q::cCast_XetwcfRP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ezJGWAGI, HV_BINOP_ADD, 1, m, &cBinop_ezJGWAGI_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_80go78s6, HV_BINOP_GREATER_THAN, 0, m, &cBinop_80go78s6_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XPPO2Drr, HV_BINOP_EQ, 0, m, &cBinop_XPPO2Drr_sendMessage);
}

void Heavy_WSTD_3Q::cCast_HM6O0Nla_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0wIti6fN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_um5EAI0V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ARxlq0MU_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_XlIHfeDt, 0, m, &cIf_XlIHfeDt_sendMessage);
}

void Heavy_WSTD_3Q::cIf_XlIHfeDt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_7T7y1UZb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_8Lva51nd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_TKgd7Byg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_alK4Hzgk_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_yQ4DIARG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_lyFjKAMO, HV_BINOP_POW, 0, m, &cBinop_lyFjKAMO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_lyFjKAMO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BnZyr5qg, 0, m, &cIf_BnZyr5qg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_uxSCzZPC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Cnk5jwjC_sendMessage);
}

void Heavy_WSTD_3Q::cCast_i422Xnii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Zm8QCthb_sendMessage);
}

void Heavy_WSTD_3Q::cCast_tdiJWFoL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8Lva51nd, 0, m, &cIf_8Lva51nd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Zm8QCthb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8Lva51nd, 1, m, &cIf_8Lva51nd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_alK4Hzgk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_uxSCzZPC_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_TKgd7Byg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_BnZyr5qg, 0, m, &cIf_BnZyr5qg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Cnk5jwjC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lyFjKAMO, HV_BINOP_POW, 1, m, &cBinop_lyFjKAMO_sendMessage);
  cMsg_yQ4DIARG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_BnZyr5qg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_KvlitUgZ_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iYylFnJ5_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_nio0xBg8_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_ARxlq0MU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XlIHfeDt, 1, m, &cIf_XlIHfeDt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7T7y1UZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WRS0GPVv, HV_BINOP_GREATER_THAN, 1, m, &cBinop_WRS0GPVv_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wcYNRloL, HV_BINOP_EQ, 1, m, &cBinop_wcYNRloL_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_I1SNvNIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_tvqQKYPz, HV_BINOP_ADD, 0, m, &cBinop_tvqQKYPz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_tvqQKYPz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_i422Xnii_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tdiJWFoL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WRS0GPVv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BnZyr5qg, 1, m, &cIf_BnZyr5qg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wcYNRloL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vLiqhSTx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_vLiqhSTx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_KvlitUgZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iYylFnJ5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_nio0xBg8_sendMessage);
}

void Heavy_WSTD_3Q::cCast_h3rE58qC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I1SNvNIf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_lGF8HTqy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_um5EAI0V, 0, m, &cVar_um5EAI0V_sendMessage);
}

void Heavy_WSTD_3Q::cCast_klgdkJoX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tvqQKYPz, HV_BINOP_ADD, 1, m, &cBinop_tvqQKYPz_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WRS0GPVv, HV_BINOP_GREATER_THAN, 0, m, &cBinop_WRS0GPVv_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wcYNRloL, HV_BINOP_EQ, 0, m, &cBinop_wcYNRloL_sendMessage);
}

void Heavy_WSTD_3Q::cVar_6K7KKgbV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_i2rxfTnv_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_QugGQpci, 0, m, &cIf_QugGQpci_sendMessage);
}

void Heavy_WSTD_3Q::cIf_QugGQpci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_4gLQl2zP_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_rbk0ifCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_wpkToShs_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_jg5QG7s6_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_G6x9danT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_LmRXQrgF, HV_BINOP_POW, 0, m, &cBinop_LmRXQrgF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_LmRXQrgF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U9Gl6t5Y, 0, m, &cIf_U9Gl6t5Y_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_clM22pVJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_jUoYTR8q_sendMessage);
}

void Heavy_WSTD_3Q::cCast_nE9zH92F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rbk0ifCa, 0, m, &cIf_rbk0ifCa_sendMessage);
}

void Heavy_WSTD_3Q::cCast_5bO45EoP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_uN2ozgQV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_uN2ozgQV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rbk0ifCa, 1, m, &cIf_rbk0ifCa_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jg5QG7s6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_clM22pVJ_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_wpkToShs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_U9Gl6t5Y, 0, m, &cIf_U9Gl6t5Y_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jUoYTR8q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LmRXQrgF, HV_BINOP_POW, 1, m, &cBinop_LmRXQrgF_sendMessage);
  cMsg_G6x9danT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_U9Gl6t5Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_EImZXKEC, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_i2rxfTnv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QugGQpci, 1, m, &cIf_QugGQpci_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4gLQl2zP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oJKTSq4F, HV_BINOP_GREATER_THAN, 1, m, &cBinop_oJKTSq4F_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_O9kIt49E, HV_BINOP_EQ, 1, m, &cBinop_O9kIt49E_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_hwUS2qq3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_G1FudZaa, HV_BINOP_ADD, 0, m, &cBinop_G1FudZaa_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_G1FudZaa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5bO45EoP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nE9zH92F_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_oJKTSq4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U9Gl6t5Y, 1, m, &cIf_U9Gl6t5Y_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_O9kIt49E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qFqw6RML_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_qFqw6RML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_EImZXKEC, m);
}

void Heavy_WSTD_3Q::cCast_6g5gfIuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6K7KKgbV, 0, m, &cVar_6K7KKgbV_sendMessage);
}

void Heavy_WSTD_3Q::cCast_38vZfqam_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hwUS2qq3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_p9SZ7PaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_G1FudZaa, HV_BINOP_ADD, 1, m, &cBinop_G1FudZaa_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_oJKTSq4F, HV_BINOP_GREATER_THAN, 0, m, &cBinop_oJKTSq4F_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_O9kIt49E, HV_BINOP_EQ, 0, m, &cBinop_O9kIt49E_sendMessage);
}

void Heavy_WSTD_3Q::cIf_zNsURazG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_p0Yiwb6q, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_ANUhF3l8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_AGTeKrkG, 0, m, &cSlice_AGTeKrkG_sendMessage);
      break;
    }
    default: {
      cSwitchcase_e1lp8YDz_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_AGTeKrkG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_UKHjpfXO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_UKHjpfXO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_GRtmfjUn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UKHjpfXO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_UKHjpfXO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PDKjVEJT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_e1lp8YDz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_dNLi7sMo, 0, m, &cSlice_dNLi7sMo_sendMessage);
      break;
    }
    default: {
      cSwitchcase_cGgNGLYl_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_dNLi7sMo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_SP3dns0t_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_SP3dns0t_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_KljjVvzc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SP3dns0t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_SP3dns0t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vR7Hcnwd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_v4ma11dY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9GLivCxM, 0, m, &cSlice_9GLivCxM_sendMessage);
      break;
    }
    default: {
      cSwitchcase_usimqyvc_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_9GLivCxM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_zVy8SZWp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_zVy8SZWp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_XEKLihdL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zVy8SZWp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_zVy8SZWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fERXOpmo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_usimqyvc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_axW1C7MF, 0, m, &cSlice_axW1C7MF_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_axW1C7MF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_yk8vaQJV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_yk8vaQJV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_k61tyITU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yk8vaQJV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_yk8vaQJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_T5oUzL6T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_aux1SU9A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EI11ewnL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_j02kkfHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1WAMXRht, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_4ajreCTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_e2OkLuhA, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_d8I5qyY3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qUig6pxo, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_FyDMugKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ul95qGZT, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_zXgJb00c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_oGLtCxtX_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_oGLtCxtX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tcNuxzEy, HV_BINOP_DIVIDE, 1, m, &cBinop_tcNuxzEy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zxphkhlM_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_aZVGXnO5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_wB96VSi3_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_WBYuFPc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_aZVGXnO5_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wB96VSi3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tcNuxzEy, HV_BINOP_DIVIDE, 0, m, &cBinop_tcNuxzEy_sendMessage);
}

void Heavy_WSTD_3Q::cCast_zxphkhlM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WBYuFPc4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_tcNuxzEy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dYl9m1o8, HV_BINOP_MULTIPLY, 1, m, &cBinop_dYl9m1o8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dYl9m1o8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tvx8HfOI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MR6MFYqD_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_OQhvIdlU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fu83QjfA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_SndfaHO4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_E57M5dTh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_pwukWjjy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_JNrJq3tg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_JNrJq3tg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dYl9m1o8, HV_BINOP_MULTIPLY, 0, m, &cBinop_dYl9m1o8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3ytDwzaN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_RVHX3EZg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_RVHX3EZg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KfiKABkx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_wapCMolw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_E84OseML, 1, m, &cVar_E84OseML_sendMessage);
}

void Heavy_WSTD_3Q::cVar_E84OseML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w85Mxl8X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_beOyIQX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x1fHuL0i, HV_BINOP_MULTIPLY, 1, m, &cBinop_x1fHuL0i_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_OLZbyHsL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_beOyIQX1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NWpe0Ost_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_zQZP5hCE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zQZP5hCE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w1C3uRp7, HV_BINOP_MULTIPLY, 1, m, &cBinop_w1C3uRp7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1Q0JWt33_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fUXOLSr1, HV_BINOP_MULTIPLY, 1, m, &cBinop_fUXOLSr1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3xRskJG8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_1Q0JWt33_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_tbZKuKdO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w5szpzzX, HV_BINOP_MULTIPLY, 1, m, &cBinop_w5szpzzX_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_SFMoA12G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_opq58938_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_opq58938_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NAJGIX9W, HV_BINOP_MULTIPLY, 1, m, &cBinop_NAJGIX9W_sendMessage);
}

void Heavy_WSTD_3Q::cVar_GUq8zO3W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zRyvWAaV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_pwukWjjy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HKLLTiKF_sendMessage);
}

void Heavy_WSTD_3Q::cVar_O2A7DT4m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_3ytDwzaN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_tvx8HfOI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_OQhvIdlU_sendMessage);
}

void Heavy_WSTD_3Q::cCast_MR6MFYqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_SndfaHO4_sendMessage);
}

void Heavy_WSTD_3Q::cSend_fu83QjfA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DNjIZwlF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_E57M5dTh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_n2ILdULZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_NkjPWHkz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HQh47ZhD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_KfiKABkx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_6KGH08My_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6KGH08My_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3UWHavl3, HV_BINOP_MULTIPLY, 1, m, &cBinop_3UWHavl3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3UWHavl3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_owQ1mmhl_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_owQ1mmhl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NkjPWHkz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_w85Mxl8X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_pF9t0YP7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pF9t0YP7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1W9IkqPU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_waFShc9M_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HuuK17JY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2ZWnf68X_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LkcUoRbL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3M6VV0f6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_x1fHuL0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aux1SU9A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_w1C3uRp7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j02kkfHF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_fUXOLSr1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4ajreCTY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_w5szpzzX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d8I5qyY3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_NAJGIX9W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FyDMugKg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_kwNVh5Tp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_O2A7DT4m, 1, m, &cVar_O2A7DT4m_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ncCipAGM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GUq8zO3W, 0, m, &cVar_GUq8zO3W_sendMessage);
}

void Heavy_WSTD_3Q::cCast_HuuK17JY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w5szpzzX, HV_BINOP_MULTIPLY, 0, m, &cBinop_w5szpzzX_sendMessage);
}

void Heavy_WSTD_3Q::cCast_3M6VV0f6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_x1fHuL0i, HV_BINOP_MULTIPLY, 0, m, &cBinop_x1fHuL0i_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2ZWnf68X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fUXOLSr1, HV_BINOP_MULTIPLY, 0, m, &cBinop_fUXOLSr1_sendMessage);
}

void Heavy_WSTD_3Q::cCast_1W9IkqPU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_LkcUoRbL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w1C3uRp7, HV_BINOP_MULTIPLY, 0, m, &cBinop_w1C3uRp7_sendMessage);
}

void Heavy_WSTD_3Q::cCast_waFShc9M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NAJGIX9W, HV_BINOP_MULTIPLY, 0, m, &cBinop_NAJGIX9W_sendMessage);
}

void Heavy_WSTD_3Q::cCast_HKLLTiKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_E84OseML, 0, m, &cVar_E84OseML_sendMessage);
}

void Heavy_WSTD_3Q::cCast_zRyvWAaV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_O2A7DT4m, 0, m, &cVar_O2A7DT4m_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_dzePqj2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UWAhCuob, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_n2mGETwv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JDAbuf1l, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_LcOSWj3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ORG3XQA2, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_5NQullXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UKHwqQyX, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_R0fLBubY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_U3Pzg3Bw_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_U3Pzg3Bw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BPO7Y7aI, HV_BINOP_DIVIDE, 1, m, &cBinop_BPO7Y7aI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3svM99YJ_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_gAWlCKf6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_epq7DuGT_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_4d7vDwd9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_gAWlCKf6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_epq7DuGT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BPO7Y7aI, HV_BINOP_DIVIDE, 0, m, &cBinop_BPO7Y7aI_sendMessage);
}

void Heavy_WSTD_3Q::cCast_3svM99YJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4d7vDwd9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_BPO7Y7aI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZMqypNgF, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZMqypNgF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ZMqypNgF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4ie6p4HB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_i5K65WZX_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_f73XzB0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_d6XxcNfw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_QkmVkBdU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_f9lOXik8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_l2cAAJkQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_wtdOkkXL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wtdOkkXL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZMqypNgF, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZMqypNgF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xQ17Deob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_gOta1wIu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gOta1wIu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NNYwjKb3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_b2kzPzIV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_n1eptIzy, HV_BINOP_MULTIPLY, 1, m, &cBinop_n1eptIzy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_FHdMN9SS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_t9sFiscd, 1, m, &cVar_t9sFiscd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YoQhfXHK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tPf9a8E4, HV_BINOP_MULTIPLY, 1, m, &cBinop_tPf9a8E4_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_dnaIiW4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Q6MM7MQf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Q6MM7MQf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BAjzYn9S, HV_BINOP_MULTIPLY, 1, m, &cBinop_BAjzYn9S_sendMessage);
}

void Heavy_WSTD_3Q::cVar_t9sFiscd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SG6baHsC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_6FkDAu6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eovkFC7D_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_l2cAAJkQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JcwIw7uc_sendMessage);
}

void Heavy_WSTD_3Q::cVar_WJQpMxts_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_xQ17Deob_sendMessage);
}

void Heavy_WSTD_3Q::cCast_i5K65WZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_QkmVkBdU_sendMessage);
}

void Heavy_WSTD_3Q::cCast_4ie6p4HB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_f73XzB0y_sendMessage);
}

void Heavy_WSTD_3Q::cSend_d6XxcNfw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nL7ee1OM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_f9lOXik8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_T1JQPv0V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_Q3tCGHia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HDwnzypY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_NNYwjKb3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_TcwkpHsN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_TcwkpHsN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZJ83yUCa, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZJ83yUCa_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ZJ83yUCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_xzVmAEci_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xzVmAEci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Q3tCGHia_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_SG6baHsC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_js8HstAG_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_js8HstAG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_S85k9A3U_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qEJXNvyk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rXO1GHsF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2ab5PYpz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_mnSruftM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dzePqj2h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_n1eptIzy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n2mGETwv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_tPf9a8E4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LcOSWj3r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_BAjzYn9S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5NQullXc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_3SMyRQ50_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6FkDAu6u, 0, m, &cVar_6FkDAu6u_sendMessage);
}

void Heavy_WSTD_3Q::cCast_GqsNvTaE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WJQpMxts, 1, m, &cVar_WJQpMxts_sendMessage);
}

void Heavy_WSTD_3Q::cCast_eovkFC7D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WJQpMxts, 0, m, &cVar_WJQpMxts_sendMessage);
}

void Heavy_WSTD_3Q::cCast_JcwIw7uc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_t9sFiscd, 0, m, &cVar_t9sFiscd_sendMessage);
}

void Heavy_WSTD_3Q::cCast_rXO1GHsF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_n1eptIzy, HV_BINOP_MULTIPLY, 0, m, &cBinop_n1eptIzy_sendMessage);
}

void Heavy_WSTD_3Q::cCast_S85k9A3U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BAjzYn9S, HV_BINOP_MULTIPLY, 0, m, &cBinop_BAjzYn9S_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2ab5PYpz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mnSruftM, HV_BINOP_MULTIPLY, 0, m, &cBinop_mnSruftM_sendMessage);
}

void Heavy_WSTD_3Q::cCast_qEJXNvyk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tPf9a8E4, HV_BINOP_MULTIPLY, 0, m, &cBinop_tPf9a8E4_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_eZNoIp7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ixoHh2vN, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_2AOqK5OW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_s1lza5bT, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_hIlNE3ap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tuagJxEp, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_csSoNiwo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MmKKMS8E, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_jmcowVb0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_C3j9GkWc, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_vEm9mvho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SoKXrXSv_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_SoKXrXSv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6uwAFqRq, HV_BINOP_DIVIDE, 1, m, &cBinop_6uwAFqRq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ef84D1CH_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_3BLwopCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_P6nsjEkc_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_jsOyAE26_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_3BLwopCJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_P6nsjEkc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6uwAFqRq, HV_BINOP_DIVIDE, 0, m, &cBinop_6uwAFqRq_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Ef84D1CH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jsOyAE26_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_6uwAFqRq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A8dQHQvQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_A8dQHQvQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_A8dQHQvQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_q8ZJhkpq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8ViDfDMI_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_JZSlF2pw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_v3zvh1ux_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_h3TWL3pO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_T3ZgzA1A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_RU5uuiHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_j1VBA9Vx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_j1VBA9Vx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A8dQHQvQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_A8dQHQvQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BcNQnm6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_deoI3jSO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_deoI3jSO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_98sCKhEC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_uWpHlM3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KMVI0tIX, HV_BINOP_MULTIPLY, 1, m, &cBinop_KMVI0tIX_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_N2oJY714_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_YwvxpdDj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YwvxpdDj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_uWpHlM3u_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_zI7cWgw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_VUV15k0J_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_VUV15k0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xIZO3URb, HV_BINOP_MULTIPLY, 1, m, &cBinop_xIZO3URb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rhgqLgSa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Bx0jawL, HV_BINOP_MULTIPLY, 1, m, &cBinop_2Bx0jawL_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_fQTKLgr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_MR6A2BHJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MR6A2BHJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_rhgqLgSa_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7uAsbQzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_j4StFXQY, 1, m, &cVar_j4StFXQY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gbnEYh0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QB1ewlnG, HV_BINOP_MULTIPLY, 1, m, &cBinop_QB1ewlnG_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_l9kOOP4o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_My617zuL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_My617zuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4KfNUE0a, HV_BINOP_MULTIPLY, 1, m, &cBinop_4KfNUE0a_sendMessage);
}

void Heavy_WSTD_3Q::cVar_j4StFXQY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3sPpgAv6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_vZ3aLfFO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ksq2HWMT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_RU5uuiHC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XHNdfPqb_sendMessage);
}

void Heavy_WSTD_3Q::cVar_5S6Q54Sc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_BcNQnm6I_sendMessage);
}

void Heavy_WSTD_3Q::cCast_q8ZJhkpq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_JZSlF2pw_sendMessage);
}

void Heavy_WSTD_3Q::cCast_8ViDfDMI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_h3TWL3pO_sendMessage);
}

void Heavy_WSTD_3Q::cSend_v3zvh1ux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kzexmikP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_T3ZgzA1A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EHmcnDn2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_IWJOddtB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NZkuTUO5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_98sCKhEC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_6fSOoB1Q_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6fSOoB1Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wm7YDQtD, HV_BINOP_MULTIPLY, 1, m, &cBinop_Wm7YDQtD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Wm7YDQtD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_SoR7eV6p_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SoR7eV6p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IWJOddtB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_3sPpgAv6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_hmkUrWEl_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_hmkUrWEl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ELojhr6h_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5gIvw6lj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zvpjNXzc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VcPjmLju_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_s6Hd6UTa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Bz437peZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_KMVI0tIX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eZNoIp7l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_xIZO3URb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2AOqK5OW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_2Bx0jawL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hIlNE3ap_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_QB1ewlnG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_csSoNiwo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_4KfNUE0a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jmcowVb0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_U7v2fcOu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vZ3aLfFO, 0, m, &cVar_vZ3aLfFO_sendMessage);
}

void Heavy_WSTD_3Q::cCast_rg73gm4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5S6Q54Sc, 1, m, &cVar_5S6Q54Sc_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ELojhr6h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_VcPjmLju_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2Bx0jawL, HV_BINOP_MULTIPLY, 0, m, &cBinop_2Bx0jawL_sendMessage);
}

void Heavy_WSTD_3Q::cCast_5gIvw6lj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4KfNUE0a, HV_BINOP_MULTIPLY, 0, m, &cBinop_4KfNUE0a_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Bz437peZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KMVI0tIX, HV_BINOP_MULTIPLY, 0, m, &cBinop_KMVI0tIX_sendMessage);
}

void Heavy_WSTD_3Q::cCast_s6Hd6UTa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xIZO3URb, HV_BINOP_MULTIPLY, 0, m, &cBinop_xIZO3URb_sendMessage);
}

void Heavy_WSTD_3Q::cCast_zvpjNXzc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QB1ewlnG, HV_BINOP_MULTIPLY, 0, m, &cBinop_QB1ewlnG_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Ksq2HWMT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5S6Q54Sc, 0, m, &cVar_5S6Q54Sc_sendMessage);
}

void Heavy_WSTD_3Q::cCast_XHNdfPqb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_j4StFXQY, 0, m, &cVar_j4StFXQY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_KvlitUgZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zNsURazG, 1, m, &cIf_zNsURazG_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_0p0j7B3T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_p0Yiwb6q, m);
}

void Heavy_WSTD_3Q::cBinop_iYylFnJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0p0j7B3T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_nio0xBg8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zNsURazG, 0, m, &cIf_zNsURazG_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_GXDBDnXi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_OcOjo4PN, 0, m, &cSlice_OcOjo4PN_sendMessage);
      break;
    }
    default: {
      cSwitchcase_yd9JHYqO_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_OcOjo4PN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_3iIH6GtT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_3iIH6GtT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_D1OZANoJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3iIH6GtT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_3iIH6GtT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AlywEk4N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_INnNSc5H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_MP7k2FuO_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_nIe1pZ5f, 0, m, &cIf_nIe1pZ5f_sendMessage);
}

void Heavy_WSTD_3Q::cIf_nIe1pZ5f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_7B5NEHMl_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_hgzLEwuW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_i1gakCqZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_iudO5f7j_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_ZuslymTN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6Aiclp76, HV_BINOP_POW, 0, m, &cBinop_6Aiclp76_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6Aiclp76_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FCLlWEw2, 0, m, &cIf_FCLlWEw2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_nXRKUeyZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_PeFiCiRm_sendMessage);
}

void Heavy_WSTD_3Q::cCast_D88x1eRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hgzLEwuW, 0, m, &cIf_hgzLEwuW_sendMessage);
}

void Heavy_WSTD_3Q::cCast_R9iVgkC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_AjG0p9rx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_AjG0p9rx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hgzLEwuW, 1, m, &cIf_hgzLEwuW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iudO5f7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_nXRKUeyZ_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_i1gakCqZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_FCLlWEw2, 0, m, &cIf_FCLlWEw2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PeFiCiRm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6Aiclp76, HV_BINOP_POW, 1, m, &cBinop_6Aiclp76_sendMessage);
  cMsg_ZuslymTN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_FCLlWEw2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_HbL7tmlA, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_MP7k2FuO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nIe1pZ5f, 1, m, &cIf_nIe1pZ5f_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7B5NEHMl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4Pwxemi5, HV_BINOP_GREATER_THAN, 1, m, &cBinop_4Pwxemi5_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_V4D2lE8z, HV_BINOP_EQ, 1, m, &cBinop_V4D2lE8z_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_F9SfufSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZcJWUNw8, HV_BINOP_ADD, 0, m, &cBinop_ZcJWUNw8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ZcJWUNw8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_R9iVgkC2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_D88x1eRg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4Pwxemi5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FCLlWEw2, 1, m, &cIf_FCLlWEw2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_V4D2lE8z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1oIiZAOH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_1oIiZAOH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_HbL7tmlA, m);
}

void Heavy_WSTD_3Q::cCast_gEgyNygY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F9SfufSZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_hWVXIzYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_INnNSc5H, 0, m, &cVar_INnNSc5H_sendMessage);
}

void Heavy_WSTD_3Q::cCast_sKHmsFke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZcJWUNw8, HV_BINOP_ADD, 1, m, &cBinop_ZcJWUNw8_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4Pwxemi5, HV_BINOP_GREATER_THAN, 0, m, &cBinop_4Pwxemi5_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_V4D2lE8z, HV_BINOP_EQ, 0, m, &cBinop_V4D2lE8z_sendMessage);
}

void Heavy_WSTD_3Q::cVar_9sAtPRrg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_154q2OdM_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_PpBOTr3M, 0, m, &cIf_PpBOTr3M_sendMessage);
}

void Heavy_WSTD_3Q::cIf_PpBOTr3M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_7I2gVXDb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_PjD9uTp9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_56ZjkOZl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_36w7OjOQ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_U8raZsgc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_nJB0VH40, HV_BINOP_POW, 0, m, &cBinop_nJB0VH40_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_nJB0VH40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WG9lNND8, 0, m, &cIf_WG9lNND8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zEgtKZOd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_BeIhLM7E_sendMessage);
}

void Heavy_WSTD_3Q::cCast_I7CAxeHp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_9lygLoAv_sendMessage);
}

void Heavy_WSTD_3Q::cCast_fR976nAh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PjD9uTp9, 0, m, &cIf_PjD9uTp9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9lygLoAv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PjD9uTp9, 1, m, &cIf_PjD9uTp9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_36w7OjOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_zEgtKZOd_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_56ZjkOZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_WG9lNND8, 0, m, &cIf_WG9lNND8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BeIhLM7E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nJB0VH40, HV_BINOP_POW, 1, m, &cBinop_nJB0VH40_sendMessage);
  cMsg_U8raZsgc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_WG9lNND8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_d63c7Kq0_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bsEb9PIJ_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_JEP8Qmct_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_154q2OdM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PpBOTr3M, 1, m, &cIf_PpBOTr3M_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7I2gVXDb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pua5liL1, HV_BINOP_GREATER_THAN, 1, m, &cBinop_pua5liL1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jj25Mkf7, HV_BINOP_EQ, 1, m, &cBinop_Jj25Mkf7_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_GuS97kQ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CnD1roHE, HV_BINOP_ADD, 0, m, &cBinop_CnD1roHE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CnD1roHE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_I7CAxeHp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fR976nAh_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pua5liL1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WG9lNND8, 1, m, &cIf_WG9lNND8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Jj25Mkf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CRE3wd8O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_CRE3wd8O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_d63c7Kq0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bsEb9PIJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_JEP8Qmct_sendMessage);
}

void Heavy_WSTD_3Q::cCast_kd9JHx5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GuS97kQ3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_D8xeHo5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9sAtPRrg, 0, m, &cVar_9sAtPRrg_sendMessage);
}

void Heavy_WSTD_3Q::cCast_e4i0V9zl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CnD1roHE, HV_BINOP_ADD, 1, m, &cBinop_CnD1roHE_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_pua5liL1, HV_BINOP_GREATER_THAN, 0, m, &cBinop_pua5liL1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jj25Mkf7, HV_BINOP_EQ, 0, m, &cBinop_Jj25Mkf7_sendMessage);
}

void Heavy_WSTD_3Q::cVar_wDCT7eXJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_OHyFzTnU_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_rjFzu4jZ, 0, m, &cIf_rjFzu4jZ_sendMessage);
}

void Heavy_WSTD_3Q::cIf_rjFzu4jZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_aqKmdrF3_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_0IUz2f4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_McH1WUN8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_tXZY3Zrj_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_fV5gk8SO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mHx1Oc6o, HV_BINOP_POW, 0, m, &cBinop_mHx1Oc6o_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_mHx1Oc6o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GuRpe4Ve, 0, m, &cIf_GuRpe4Ve_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5lwrd6QI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_EpnWRV3x_sendMessage);
}

void Heavy_WSTD_3Q::cCast_WIg5CEqR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_n1IMWyWU_sendMessage);
}

void Heavy_WSTD_3Q::cCast_C6tNCKfg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0IUz2f4y, 0, m, &cIf_0IUz2f4y_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_n1IMWyWU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0IUz2f4y, 1, m, &cIf_0IUz2f4y_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_tXZY3Zrj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_5lwrd6QI_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_McH1WUN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_GuRpe4Ve, 0, m, &cIf_GuRpe4Ve_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_EpnWRV3x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mHx1Oc6o, HV_BINOP_POW, 1, m, &cBinop_mHx1Oc6o_sendMessage);
  cMsg_fV5gk8SO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_GuRpe4Ve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_ZiPR4jzy, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_OHyFzTnU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rjFzu4jZ, 1, m, &cIf_rjFzu4jZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_aqKmdrF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_66AaMgLF, HV_BINOP_GREATER_THAN, 1, m, &cBinop_66AaMgLF_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PlnvV4rv, HV_BINOP_EQ, 1, m, &cBinop_PlnvV4rv_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_XINdJ86u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VLjN5ucu, HV_BINOP_ADD, 0, m, &cBinop_VLjN5ucu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_VLjN5ucu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WIg5CEqR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C6tNCKfg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_66AaMgLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GuRpe4Ve, 1, m, &cIf_GuRpe4Ve_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PlnvV4rv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AbeqJoVy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_AbeqJoVy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_ZiPR4jzy, m);
}

void Heavy_WSTD_3Q::cCast_YM27BjJm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VLjN5ucu, HV_BINOP_ADD, 1, m, &cBinop_VLjN5ucu_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_66AaMgLF, HV_BINOP_GREATER_THAN, 0, m, &cBinop_66AaMgLF_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PlnvV4rv, HV_BINOP_EQ, 0, m, &cBinop_PlnvV4rv_sendMessage);
}

void Heavy_WSTD_3Q::cCast_AkhlSbC9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wDCT7eXJ, 0, m, &cVar_wDCT7eXJ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_lec2EjI0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XINdJ86u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_1QvnIlMH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_YCwMU8jl, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_WYsgT8sT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_C1TK6wkD, 0, m, &cSlice_C1TK6wkD_sendMessage);
      break;
    }
    default: {
      cSwitchcase_3XhmDOhA_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_C1TK6wkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_juksP4s4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_juksP4s4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_XHpwpgq7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_juksP4s4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_juksP4s4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_s97ZefgI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_3XhmDOhA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_BjBDbzV6, 0, m, &cSlice_BjBDbzV6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_GXDBDnXi_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_BjBDbzV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Rop9tTeQ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Rop9tTeQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_Eal9tcJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Rop9tTeQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_Rop9tTeQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_byyZKIwX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_yd9JHYqO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_48B64ovD, 0, m, &cSlice_48B64ovD_sendMessage);
      break;
    }
    default: {
      cSwitchcase_F0uB9b99_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_48B64ovD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_zKgNAQC3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_zKgNAQC3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_ImwSkEzZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zKgNAQC3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_zKgNAQC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_okkEDIx1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_F0uB9b99_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_hSFNEClR, 0, m, &cSlice_hSFNEClR_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_hSFNEClR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xdxKIN7p_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xdxKIN7p_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_3nnhlgZq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xdxKIN7p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_xdxKIN7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_iIJaKeJF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_JfocG4Wh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8HMvtAGd, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_iYUYVwJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tIAn1zmQ, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_3ZLpNQOz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QuBm5rX0, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_C7uaLIIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nWARzAsP, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Vk7oITCK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ETNpItDQ, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_qzTs9QhZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rXpCDkvd_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_rXpCDkvd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cApFGrZO, HV_BINOP_DIVIDE, 1, m, &cBinop_cApFGrZO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w1UJO7Pw_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_TYCPWi7x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_wJZLVNYf_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_spCekacs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_TYCPWi7x_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wJZLVNYf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cApFGrZO, HV_BINOP_DIVIDE, 0, m, &cBinop_cApFGrZO_sendMessage);
}

void Heavy_WSTD_3Q::cCast_w1UJO7Pw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_spCekacs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_cApFGrZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PhH3YTL3, HV_BINOP_MULTIPLY, 1, m, &cBinop_PhH3YTL3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PhH3YTL3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1O5OKP64_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MxqCqb7E_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_3VsAuP7H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NkeebdF9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_fdrFnjRb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3O7W6dS4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_wXcugilO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_jcZvPIIf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jcZvPIIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PhH3YTL3, HV_BINOP_MULTIPLY, 0, m, &cBinop_PhH3YTL3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7YEtDOXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_nWJF6QqF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_nWJF6QqF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BQdbCZom_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_XpuNb8WU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zH0LXJyK, 1, m, &cVar_zH0LXJyK_sendMessage);
}

void Heavy_WSTD_3Q::cVar_zH0LXJyK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7nQsWv9g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_5xa10fu7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vesjZN1g, HV_BINOP_MULTIPLY, 1, m, &cBinop_vesjZN1g_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yLptm1dD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_5xa10fu7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Oy1T1zMo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_9zYvLEAp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9zYvLEAp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZuySSA7N, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZuySSA7N_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NmA4XrRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wh4D2RXZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_wh4D2RXZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_fmvJECtx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_NmA4XrRs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5SX6i9LH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9HGMS2aE, HV_BINOP_MULTIPLY, 1, m, &cBinop_9HGMS2aE_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_74hUczmj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_KjxKBrTK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_KjxKBrTK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sSrqDYpu, HV_BINOP_MULTIPLY, 1, m, &cBinop_sSrqDYpu_sendMessage);
}

void Heavy_WSTD_3Q::cVar_2Ndu72Uk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1wswlL0p_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_wXcugilO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1JcwWPjG_sendMessage);
}

void Heavy_WSTD_3Q::cVar_FXdDNwEV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_7YEtDOXl_sendMessage);
}

void Heavy_WSTD_3Q::cCast_MxqCqb7E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_fdrFnjRb_sendMessage);
}

void Heavy_WSTD_3Q::cCast_1O5OKP64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_3VsAuP7H_sendMessage);
}

void Heavy_WSTD_3Q::cSend_NkeebdF9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9B1T2xbn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_3O7W6dS4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KQ3omudN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_ZHp8KowN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AOejFoe8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_BQdbCZom_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Ee7nJrtS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Ee7nJrtS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mzTTnmWf, HV_BINOP_MULTIPLY, 1, m, &cBinop_mzTTnmWf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_mzTTnmWf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_WRgJxMVG_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WRgJxMVG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZHp8KowN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_7nQsWv9g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_zNREwacO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zNREwacO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7E2oXWQU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DOLmRSxD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rRVgcJks_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wJxXcS3h_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vXpRlQC3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_J0hBmVCU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vesjZN1g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JfocG4Wh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ZuySSA7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iYUYVwJZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_wh4D2RXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3ZLpNQOz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_9HGMS2aE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C7uaLIIk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_sSrqDYpu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Vk7oITCK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_5DTG6DxN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2Ndu72Uk, 0, m, &cVar_2Ndu72Uk_sendMessage);
}

void Heavy_WSTD_3Q::cCast_WI1qpRWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FXdDNwEV, 1, m, &cVar_FXdDNwEV_sendMessage);
}

void Heavy_WSTD_3Q::cCast_J0hBmVCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vesjZN1g, HV_BINOP_MULTIPLY, 0, m, &cBinop_vesjZN1g_sendMessage);
}

void Heavy_WSTD_3Q::cCast_rRVgcJks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9HGMS2aE, HV_BINOP_MULTIPLY, 0, m, &cBinop_9HGMS2aE_sendMessage);
}

void Heavy_WSTD_3Q::cCast_DOLmRSxD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sSrqDYpu, HV_BINOP_MULTIPLY, 0, m, &cBinop_sSrqDYpu_sendMessage);
}

void Heavy_WSTD_3Q::cCast_vXpRlQC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZuySSA7N, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZuySSA7N_sendMessage);
}

void Heavy_WSTD_3Q::cCast_7E2oXWQU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_wJxXcS3h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wh4D2RXZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_wh4D2RXZ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_1JcwWPjG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zH0LXJyK, 0, m, &cVar_zH0LXJyK_sendMessage);
}

void Heavy_WSTD_3Q::cCast_1wswlL0p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FXdDNwEV, 0, m, &cVar_FXdDNwEV_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_BXvU83lz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sIxI6B5A, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_07QdDoOo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aDcDA4hB, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_sUmACYYk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zx7h5ibi, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_RL1k52oc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QVIrEG1r, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_vvBMsa02_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_znYsC5gD_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_znYsC5gD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nI8YCaTL, HV_BINOP_DIVIDE, 1, m, &cBinop_nI8YCaTL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bixEka1W_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_Mk30IkkI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_aK1MkFdk_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_xKmKFfVX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Mk30IkkI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_aK1MkFdk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nI8YCaTL, HV_BINOP_DIVIDE, 0, m, &cBinop_nI8YCaTL_sendMessage);
}

void Heavy_WSTD_3Q::cCast_bixEka1W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xKmKFfVX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_nI8YCaTL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_grEYILya, HV_BINOP_MULTIPLY, 1, m, &cBinop_grEYILya_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_grEYILya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RKc032p7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iLGggi5V_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_pbpmunDY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tzbQjIsz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_5AJRcEFP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_plZ3zT3p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Dc3Yvuqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_QiB8R7Va_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_QiB8R7Va_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_grEYILya, HV_BINOP_MULTIPLY, 0, m, &cBinop_grEYILya_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Dm4HwqKy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_mYXdYsWJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_mYXdYsWJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1rlnCEe0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Tg2QVT4T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SbM7pZVx, HV_BINOP_MULTIPLY, 1, m, &cBinop_SbM7pZVx_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_E4RzUcnz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_w9PIKwto, 1, m, &cVar_w9PIKwto_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5AxnQuX6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IpyuyyI4, HV_BINOP_MULTIPLY, 1, m, &cBinop_IpyuyyI4_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_zIixQcUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_CkNzhJUi_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CkNzhJUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zjYBmmi2, HV_BINOP_MULTIPLY, 1, m, &cBinop_zjYBmmi2_sendMessage);
}

void Heavy_WSTD_3Q::cVar_w9PIKwto_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VWnvRqlL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_IYo0mRdH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AGCTb32e_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_Dc3Yvuqi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TYK3ENcs_sendMessage);
}

void Heavy_WSTD_3Q::cVar_vKiF76Xm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Dm4HwqKy_sendMessage);
}

void Heavy_WSTD_3Q::cCast_iLGggi5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_5AJRcEFP_sendMessage);
}

void Heavy_WSTD_3Q::cCast_RKc032p7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_pbpmunDY_sendMessage);
}

void Heavy_WSTD_3Q::cSend_tzbQjIsz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xbyfX8yl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_plZ3zT3p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3TTcRhEE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_uS2nDULc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ToQ25979_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_1rlnCEe0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_gCRjiFyK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gCRjiFyK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ODzH6zDR, HV_BINOP_MULTIPLY, 1, m, &cBinop_ODzH6zDR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ODzH6zDR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_DwgHddaz_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_DwgHddaz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uS2nDULc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_VWnvRqlL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_vCKtEjdZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vCKtEjdZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ArF4zMG5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BfKFX0tx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jMucQImO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AKB1tvZp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CM4z62Kq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BXvU83lz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_SbM7pZVx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_07QdDoOo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_IpyuyyI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sUmACYYk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_zjYBmmi2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RL1k52oc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_LtAepNBX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IYo0mRdH, 0, m, &cVar_IYo0mRdH_sendMessage);
}

void Heavy_WSTD_3Q::cCast_NTMQ1QGa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vKiF76Xm, 1, m, &cVar_vKiF76Xm_sendMessage);
}

void Heavy_WSTD_3Q::cCast_TYK3ENcs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_w9PIKwto, 0, m, &cVar_w9PIKwto_sendMessage);
}

void Heavy_WSTD_3Q::cCast_AGCTb32e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vKiF76Xm, 0, m, &cVar_vKiF76Xm_sendMessage);
}

void Heavy_WSTD_3Q::cCast_BfKFX0tx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IpyuyyI4, HV_BINOP_MULTIPLY, 0, m, &cBinop_IpyuyyI4_sendMessage);
}

void Heavy_WSTD_3Q::cCast_AKB1tvZp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CM4z62Kq, HV_BINOP_MULTIPLY, 0, m, &cBinop_CM4z62Kq_sendMessage);
}

void Heavy_WSTD_3Q::cCast_jMucQImO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SbM7pZVx, HV_BINOP_MULTIPLY, 0, m, &cBinop_SbM7pZVx_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ArF4zMG5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zjYBmmi2, HV_BINOP_MULTIPLY, 0, m, &cBinop_zjYBmmi2_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_OBlMoQ14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7ipPLhUR, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_XZknpYDa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4nDatD9R, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_eQc1RmDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0OLoKptJ, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_w6ioNvGQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ccRk3ax9, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_XKsVddh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eeJ8AsEA, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_5bstRgzu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dfhfo8sE_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_dfhfo8sE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fKQL6lJf, HV_BINOP_DIVIDE, 1, m, &cBinop_fKQL6lJf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZFDXR1E1_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_FdqXSBtm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_goygDkWU_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_MXqgamPJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_FdqXSBtm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_goygDkWU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fKQL6lJf, HV_BINOP_DIVIDE, 0, m, &cBinop_fKQL6lJf_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ZFDXR1E1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MXqgamPJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_fKQL6lJf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lnkYlyU6, HV_BINOP_MULTIPLY, 1, m, &cBinop_lnkYlyU6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_lnkYlyU6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_j64zx8kk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NPOhqGs5_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_U46MpFjC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kOFETNER_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_iJu3Kio0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fDrq8QQZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_9IfnsbtE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_iGwJOzsl_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iGwJOzsl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lnkYlyU6, HV_BINOP_MULTIPLY, 0, m, &cBinop_lnkYlyU6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wb4Xeotx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_u5xjarSq_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_u5xjarSq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D3KKCbPF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_olmEHUFH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XgmWD6DY, HV_BINOP_MULTIPLY, 1, m, &cBinop_XgmWD6DY_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Pde2qjvY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_AebRNlqh_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_AebRNlqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_olmEHUFH_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_bWftEM10_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_K6SPwUzE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_K6SPwUzE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6CXA0PuG, HV_BINOP_MULTIPLY, 1, m, &cBinop_6CXA0PuG_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XnsBbHnU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_43opcpbM, HV_BINOP_MULTIPLY, 1, m, &cBinop_43opcpbM_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_2wwsVaqM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_XpNaug2J_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XpNaug2J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_XnsBbHnU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9Clhqr0C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dHmXKQ4X, 1, m, &cVar_dHmXKQ4X_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GDFlVqBJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LJ2bJZgm, HV_BINOP_MULTIPLY, 1, m, &cBinop_LJ2bJZgm_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_urfhjlec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_oumS1o3o_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_oumS1o3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_htaxz3bP, HV_BINOP_MULTIPLY, 1, m, &cBinop_htaxz3bP_sendMessage);
}

void Heavy_WSTD_3Q::cVar_dHmXKQ4X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fMmU2fI5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_2exLqDsC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N71aWr4n_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_9IfnsbtE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fxvXlJGI_sendMessage);
}

void Heavy_WSTD_3Q::cVar_WN6Awgyd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_wb4Xeotx_sendMessage);
}

void Heavy_WSTD_3Q::cCast_NPOhqGs5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_iJu3Kio0_sendMessage);
}

void Heavy_WSTD_3Q::cCast_j64zx8kk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_U46MpFjC_sendMessage);
}

void Heavy_WSTD_3Q::cSend_kOFETNER_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nAHgcNiR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_fDrq8QQZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Hl36JBKc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_v7vsawGn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_37DZq7SY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_D3KKCbPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_qFAGoO0Z_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qFAGoO0Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3KfP6ung, HV_BINOP_MULTIPLY, 1, m, &cBinop_3KfP6ung_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3KfP6ung_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_9ydt4hFQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9ydt4hFQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_v7vsawGn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_fMmU2fI5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_uqLNYjVL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_uqLNYjVL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BjlV7R7L_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g6tqEYsu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2q0hMuca_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8eKuxGDy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OE9AVtAE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7waKYYBH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XgmWD6DY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OBlMoQ14_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_6CXA0PuG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XZknpYDa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_43opcpbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eQc1RmDP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_LJ2bJZgm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w6ioNvGQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_htaxz3bP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XKsVddh0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_qV1Fzo8Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2exLqDsC, 0, m, &cVar_2exLqDsC_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Lx1SDrns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WN6Awgyd, 1, m, &cVar_WN6Awgyd_sendMessage);
}

void Heavy_WSTD_3Q::cCast_OE9AVtAE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6CXA0PuG, HV_BINOP_MULTIPLY, 0, m, &cBinop_6CXA0PuG_sendMessage);
}

void Heavy_WSTD_3Q::cCast_BjlV7R7L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_2q0hMuca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LJ2bJZgm, HV_BINOP_MULTIPLY, 0, m, &cBinop_LJ2bJZgm_sendMessage);
}

void Heavy_WSTD_3Q::cCast_8eKuxGDy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_43opcpbM, HV_BINOP_MULTIPLY, 0, m, &cBinop_43opcpbM_sendMessage);
}

void Heavy_WSTD_3Q::cCast_g6tqEYsu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_htaxz3bP, HV_BINOP_MULTIPLY, 0, m, &cBinop_htaxz3bP_sendMessage);
}

void Heavy_WSTD_3Q::cCast_7waKYYBH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XgmWD6DY, HV_BINOP_MULTIPLY, 0, m, &cBinop_XgmWD6DY_sendMessage);
}

void Heavy_WSTD_3Q::cCast_fxvXlJGI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dHmXKQ4X, 0, m, &cVar_dHmXKQ4X_sendMessage);
}

void Heavy_WSTD_3Q::cCast_N71aWr4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WN6Awgyd, 0, m, &cVar_WN6Awgyd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_d63c7Kq0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1QvnIlMH, 1, m, &cIf_1QvnIlMH_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_zNIeybuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_YCwMU8jl, m);
}

void Heavy_WSTD_3Q::cBinop_bsEb9PIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zNIeybuL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_JEP8Qmct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1QvnIlMH, 0, m, &cIf_1QvnIlMH_sendMessage);
}

void Heavy_WSTD_3Q::cVar_jpvptTQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yp1cOWgu, HV_BINOP_DIVIDE, 0, m, &cBinop_yp1cOWgu_sendMessage);
}

void Heavy_WSTD_3Q::cVar_dZVW0D7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Nfd23mIN, HV_BINOP_DIVIDE, 1, m, &cBinop_Nfd23mIN_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yp1cOWgu, HV_BINOP_DIVIDE, 1, m, &cBinop_yp1cOWgu_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_oh5gLJok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8E4wK3RZ, HV_BINOP_DIVIDE, 0, m, &cBinop_8E4wK3RZ_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_aG4sn3M0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8E4wK3RZ, HV_BINOP_DIVIDE, 1, m, &cBinop_8E4wK3RZ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_80zyfCd0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Nfd23mIN, HV_BINOP_DIVIDE, 0, m, &cBinop_Nfd23mIN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_A6pwxbgw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jpvptTQF, 0, m, &cVar_jpvptTQF_sendMessage);
}

void Heavy_WSTD_3Q::cCast_7F5l4mpD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dZVW0D7p, 0, m, &cVar_dZVW0D7p_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Nfd23mIN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_oh5gLJok_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yp1cOWgu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_aG4sn3M0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8E4wK3RZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_5z8XK1Pi_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_gt5PjDGs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_Uawi0zFQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UCZwEFLm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_O8EAwN4r_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5z8XK1Pi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_UCZwEFLm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_O8EAwN4r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_gt5PjDGs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Uawi0zFQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bz2Nt7fz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_4iw5EAr3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_ANUhF3l8_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_WYsgT8sT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_hoNuJvrl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_ANUhF3l8_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_WYsgT8sT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_YE62uyrf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_ANUhF3l8_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_WYsgT8sT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Y6UNn05O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_ANUhF3l8_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_WYsgT8sT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_bz2Nt7fz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_ANUhF3l8_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_WYsgT8sT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_zMNCuMko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_4hktxAjy, 0, m, &cVar_4hktxAjy_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_FzBVGBXy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_WVIQvl2i, 0, m, &cVar_WVIQvl2i_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Gz9sjHTX, 0, m, &cVar_Gz9sjHTX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PRNMX3Io, 0, m, &cVar_PRNMX3Io_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_nrgNcEvA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WVIQvl2i, 0, m, &cVar_WVIQvl2i_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_DshYfIDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Gz9sjHTX, 0, m, &cVar_Gz9sjHTX_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_q4O32XG4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PRNMX3Io, 0, m, &cVar_PRNMX3Io_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_RLQ2mTKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6FkDAu6u, 0, m, &cVar_6FkDAu6u_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_T5oUzL6T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GqsNvTaE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3SMyRQ50_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_PDKjVEJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FQVmzeF7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XetwcfRP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HM6O0Nla_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_fERXOpmo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6g5gfIuK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_p9SZ7PaZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_38vZfqam_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_vR7Hcnwd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lGF8HTqy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_klgdkJoX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h3rE58qC_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_5h7kQsoF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zXgJb00c_sendMessage(_c, 0, m);
  cMsg_R0fLBubY_sendMessage(_c, 0, m);
  cMsg_vEm9mvho_sendMessage(_c, 0, m);
  cMsg_qzTs9QhZ_sendMessage(_c, 0, m);
  cMsg_vvBMsa02_sendMessage(_c, 0, m);
  cMsg_5bstRgzu_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_GUq8zO3W, 0, m, &cVar_GUq8zO3W_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6FkDAu6u, 0, m, &cVar_6FkDAu6u_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vZ3aLfFO, 0, m, &cVar_vZ3aLfFO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2Ndu72Uk, 0, m, &cVar_2Ndu72Uk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IYo0mRdH, 0, m, &cVar_IYo0mRdH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2exLqDsC, 0, m, &cVar_2exLqDsC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_c2lONnp6, 0, m, &cVar_c2lONnp6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LRFkeLYk, 0, m, &cVar_LRFkeLYk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_um5EAI0V, 0, m, &cVar_um5EAI0V_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_6K7KKgbV, 0, m, &cVar_6K7KKgbV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GRtmfjUn, 0, m, &cVar_GRtmfjUn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KljjVvzc, 0, m, &cVar_KljjVvzc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XEKLihdL, 0, m, &cVar_XEKLihdL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_k61tyITU, 0, m, &cVar_k61tyITU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_D1OZANoJ, 0, m, &cVar_D1OZANoJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_INnNSc5H, 0, m, &cVar_INnNSc5H_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9sAtPRrg, 0, m, &cVar_9sAtPRrg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wDCT7eXJ, 0, m, &cVar_wDCT7eXJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XHpwpgq7, 0, m, &cVar_XHpwpgq7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Eal9tcJu, 0, m, &cVar_Eal9tcJu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ImwSkEzZ, 0, m, &cVar_ImwSkEzZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3nnhlgZq, 0, m, &cVar_3nnhlgZq_sendMessage);
  cMsg_FzBVGBXy_sendMessage(_c, 0, m);
  cMsg_zMNCuMko_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_DNjIZwlF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3UWHavl3, HV_BINOP_MULTIPLY, 0, m, &cBinop_3UWHavl3_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_n2ILdULZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_OLZbyHsL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_NWpe0Ost_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_3xRskJG8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_tbZKuKdO_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_HQh47ZhD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_wapCMolw_sendMessage);
  cMsg_SFMoA12G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_nL7ee1OM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZJ83yUCa, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZJ83yUCa_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_T1JQPv0V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_YoQhfXHK_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_HDwnzypY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mnSruftM, HV_BINOP_MULTIPLY, 1, m, &cBinop_mnSruftM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_b2kzPzIV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_FHdMN9SS_sendMessage);
  cMsg_dnaIiW4M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_kzexmikP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wm7YDQtD, HV_BINOP_MULTIPLY, 0, m, &cBinop_Wm7YDQtD_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_EHmcnDn2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N2oJY714_sendMessage(_c, 0, m);
  cMsg_zI7cWgw3_sendMessage(_c, 0, m);
  cMsg_fQTKLgr5_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_gbnEYh0b_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_NZkuTUO5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_7uAsbQzE_sendMessage);
  cMsg_l9kOOP4o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_AlywEk4N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IYo0mRdH, 0, m, &cVar_IYo0mRdH_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_iIJaKeJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NTMQ1QGa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LtAepNBX_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_s97ZefgI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hWVXIzYe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sKHmsFke_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gEgyNygY_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_okkEDIx1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AkhlSbC9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YM27BjJm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lec2EjI0_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_byyZKIwX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_D8xeHo5g_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_e4i0V9zl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kd9JHx5w_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_9B1T2xbn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mzTTnmWf, HV_BINOP_MULTIPLY, 0, m, &cBinop_mzTTnmWf_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_KQ3omudN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_yLptm1dD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Oy1T1zMo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_fmvJECtx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_5SX6i9LH_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_AOejFoe8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_XpuNb8WU_sendMessage);
  cMsg_74hUczmj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_xbyfX8yl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ODzH6zDR, HV_BINOP_MULTIPLY, 0, m, &cBinop_ODzH6zDR_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_3TTcRhEE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_5AxnQuX6_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_ToQ25979_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CM4z62Kq, HV_BINOP_MULTIPLY, 1, m, &cBinop_CM4z62Kq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Tg2QVT4T_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_E4RzUcnz_sendMessage);
  cMsg_zIixQcUB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_nAHgcNiR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3KfP6ung, HV_BINOP_MULTIPLY, 0, m, &cBinop_3KfP6ung_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_Hl36JBKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Pde2qjvY_sendMessage(_c, 0, m);
  cMsg_bWftEM10_sendMessage(_c, 0, m);
  cMsg_2wwsVaqM_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_GDFlVqBJ_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_37DZq7SY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_9Clhqr0C_sendMessage);
  cMsg_urfhjlec_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_TUM2PEhL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4hktxAjy, 0, m, &cVar_4hktxAjy_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_3Q::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9;

  // input and output vars
  hv_bufferf_t O0, O1, O2, O3, O4, O5;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));
    __hv_zero_f(VOf(O2));
    __hv_zero_f(VOf(O3));
    __hv_zero_f(VOf(O4));
    __hv_zero_f(VOf(O5));

    // process all signal functions
    __hv_line_f(&sLine_EI11ewnL, VOf(Bf0));
    __hv_line_f(&sLine_1WAMXRht, VOf(Bf1));
    __hv_line_f(&sLine_e2OkLuhA, VOf(Bf2));
    __hv_line_f(&sLine_qUig6pxo, VOf(Bf3));
    __hv_line_f(&sLine_Ul95qGZT, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_Y5N28MCe, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_uWzphsaV, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_UWAhCuob, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_JDAbuf1l, VOf(Bf1));
    __hv_line_f(&sLine_ORG3XQA2, VOf(Bf0));
    __hv_line_f(&sLine_UKHwqQyX, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_QMaImNZI, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_p0Yiwb6q, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_ixoHh2vN, VOf(Bf5));
    __hv_line_f(&sLine_s1lza5bT, VOf(Bf1));
    __hv_line_f(&sLine_tuagJxEp, VOf(Bf2));
    __hv_line_f(&sLine_MmKKMS8E, VOf(Bf4));
    __hv_line_f(&sLine_C3j9GkWc, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_nb7ZKiZ3, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_EImZXKEC, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_8HMvtAGd, VOf(Bf6));
    __hv_line_f(&sLine_tIAn1zmQ, VOf(Bf2));
    __hv_line_f(&sLine_QuBm5rX0, VOf(Bf1));
    __hv_line_f(&sLine_nWARzAsP, VOf(Bf5));
    __hv_line_f(&sLine_ETNpItDQ, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_bsPenzoi, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_HbL7tmlA, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_sIxI6B5A, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_aDcDA4hB, VOf(Bf2));
    __hv_line_f(&sLine_zx7h5ibi, VOf(Bf6));
    __hv_line_f(&sLine_QVIrEG1r, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_RatCbAyY, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_YCwMU8jl, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_7ipPLhUR, VOf(Bf8));
    __hv_line_f(&sLine_4nDatD9R, VOf(Bf2));
    __hv_line_f(&sLine_0OLoKptJ, VOf(Bf1));
    __hv_line_f(&sLine_ccRk3ax9, VOf(Bf7));
    __hv_line_f(&sLine_eeJ8AsEA, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_bl8uZm98, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_ZiPR4jzy, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf4), VIf(O4), VOf(O4));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf0), VIf(O2), VOf(O2));
    __hv_add_f(VIf(Bf7), VIf(O5), VOf(O5));
    __hv_add_f(VIf(Bf6), VIf(O3), VOf(O3));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
    __hv_store_f(outputBuffers[2]+n, VIf(O2));
    __hv_store_f(outputBuffers[3]+n, VIf(O3));
    __hv_store_f(outputBuffers[4]+n, VIf(O4));
    __hv_store_f(outputBuffers[5]+n, VIf(O5));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_3Q::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 6 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(6*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);
  bOut[2] = outputBuffers+(2*n4);
  bOut[3] = outputBuffers+(3*n4);
  bOut[4] = outputBuffers+(4*n4);
  bOut[5] = outputBuffers+(5*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_3Q::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 6 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(6*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  
  // interleave the heavy output into the output buffer
  for (int i = 0; i < 6; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+6*j] = bOut[i*n4+j];
    }
  }

  return n;
}
